@@ -19,13 +19,10 @@ package org.apache.maven.repository.internal;
  * under the License.
  */
 
-import org.apache.commons.lang3.Validate;
 import org.apache.maven.artifact.repository.metadata.Snapshot;
 import org.apache.maven.artifact.repository.metadata.SnapshotVersion;
 import org.apache.maven.artifact.repository.metadata.Versioning;
 import org.apache.maven.artifact.repository.metadata.io.xpp3.MetadataXpp3Reader;
-import org.codehaus.plexus.component.annotations.Component;
-import org.codehaus.plexus.component.annotations.Requirement;
 import org.codehaus.plexus.util.StringUtils;
 import org.eclipse.aether.RepositoryCache;
 import org.eclipse.aether.RepositoryEvent;
@@ -53,13 +50,11 @@ import org.eclipse.aether.resolution.VersionResolutionException;
 import org.eclipse.aether.resolution.VersionResult;
 import org.eclipse.aether.spi.locator.Service;
 import org.eclipse.aether.spi.locator.ServiceLocator;
-import org.eclipse.aether.spi.log.Logger;
-import org.eclipse.aether.spi.log.LoggerFactory;
-import org.eclipse.aether.spi.log.NullLoggerFactory;
 import org.eclipse.aether.util.ConfigUtils;
 
 import javax.inject.Inject;
 import javax.inject.Named;
+import javax.inject.Singleton;
 
 import java.io.File;
 import java.io.FileInputStream;
@@ -70,12 +65,13 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 
 /**
  * @author Benjamin Bentmann
  */
 @Named
-@Component( role = VersionResolver.class )
+@Singleton
 public class DefaultVersionResolver
     implements VersionResolver, Service
 {
@@ -88,17 +84,10 @@ public class DefaultVersionResolver
 
     private static final String SNAPSHOT = "SNAPSHOT";
 
-    @SuppressWarnings( "unused" )
-    @Requirement( role = LoggerFactory.class )
-    private Logger logger = NullLoggerFactory.LOGGER;
-
-    @Requirement
     private MetadataResolver metadataResolver;
 
-    @Requirement
     private SyncContextFactory syncContextFactory;
 
-    @Requirement
     private RepositoryEventDispatcher repositoryEventDispatcher;
 
     public DefaultVersionResolver()
@@ -108,53 +97,40 @@ public class DefaultVersionResolver
 
     @Inject
     DefaultVersionResolver( MetadataResolver metadataResolver, SyncContextFactory syncContextFactory,
-                            RepositoryEventDispatcher repositoryEventDispatcher, LoggerFactory loggerFactory )
+                            RepositoryEventDispatcher repositoryEventDispatcher )
     {
         setMetadataResolver( metadataResolver );
         setSyncContextFactory( syncContextFactory );
-        setLoggerFactory( loggerFactory );
         setRepositoryEventDispatcher( repositoryEventDispatcher );
     }
 
     public void initService( ServiceLocator locator )
     {
-        setLoggerFactory( locator.getService( LoggerFactory.class ) );
         setMetadataResolver( locator.getService( MetadataResolver.class ) );
         setSyncContextFactory( locator.getService( SyncContextFactory.class ) );
         setRepositoryEventDispatcher( locator.getService( RepositoryEventDispatcher.class ) );
     }
 
-    public DefaultVersionResolver setLoggerFactory( LoggerFactory loggerFactory )
-    {
-        this.logger = NullLoggerFactory.getSafeLogger( loggerFactory, getClass() );
-        return this;
-    }
-
-    void setLogger( LoggerFactory loggerFactory )
-    {
-        // plexus support
-        setLoggerFactory( loggerFactory );
-    }
-
     public DefaultVersionResolver setMetadataResolver( MetadataResolver metadataResolver )
     {
-        this.metadataResolver = Validate.notNull( metadataResolver, "metadataResolver cannot be null" );
+        this.metadataResolver = Objects.requireNonNull( metadataResolver, "metadataResolver cannot be null" );
         return this;
     }
 
     public DefaultVersionResolver setSyncContextFactory( SyncContextFactory syncContextFactory )
     {
-        this.syncContextFactory = Validate.notNull( syncContextFactory, "syncContextFactory cannot be null" );
+        this.syncContextFactory = Objects.requireNonNull( syncContextFactory, "syncContextFactory cannot be null" );
         return this;
     }
 
     public DefaultVersionResolver setRepositoryEventDispatcher( RepositoryEventDispatcher repositoryEventDispatcher )
     {
-        this.repositoryEventDispatcher = Validate.notNull( repositoryEventDispatcher,
+        this.repositoryEventDispatcher = Objects.requireNonNull( repositoryEventDispatcher,
             "repositoryEventDispatcher cannot be null" );
         return this;
     }
 
+    @SuppressWarnings( "checkstyle:methodlength" )
     public VersionResult resolveVersion( RepositorySystemSession session, VersionRequest request )
         throws VersionResolutionException
     {
@@ -480,14 +456,14 @@ public class DefaultVersionResolver
 
         ArtifactRepository repository;
 
-        public VersionInfo( String timestamp, String version, ArtifactRepository repository )
+        VersionInfo( String timestamp, String version, ArtifactRepository repository )
         {
             this.timestamp = ( timestamp != null ) ? timestamp : "";
             this.version = version;
             this.repository = repository;
         }
 
-        public boolean isOutdated( String timestamp )
+        boolean isOutdated( String timestamp )
         {
             return timestamp != null && timestamp.compareTo( this.timestamp ) > 0;
         }
@@ -517,7 +493,7 @@ public class DefaultVersionResolver
 
         private final int hashCode;
 
-        public Key( RepositorySystemSession session, VersionRequest request )
+        Key( RepositorySystemSession session, VersionRequest request )
         {
             Artifact artifact = request.getArtifact();
             groupId = artifact.getGroupId();
@@ -590,7 +566,7 @@ public class DefaultVersionResolver
 
         final Class<?> repoClass;
 
-        public Record( String version, ArtifactRepository repository )
+        Record( String version, ArtifactRepository repository )
         {
             this.version = version;
             if ( repository != null )
